function [y_lags X_stack X_vec] = create_X(y,lags)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Function that generates the VAR variables : 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Inputs :
%%%% y contains the different time series (T * k)
%%%% lags : number of lags
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Outputs : 
%%%% The variable y_lags is T-lags * k
%%%% X_stack is a 3 dimension matrix dimension * dimension*(1+dimension*lags) * T-lags and its
%%%% entries are assigned as follows : 
%%%% X_stack = [1 y_{1,t-1},y_{1,t-2},...,y_{1,t-lags},y_{2,t-1},...y_{2,t-lags},...,y_{n,t-lags},0,0,...,0  ; 0,0,... 0 1 y_{1,t-1},y_{1,t-2},...,y_{1,t-lags},y_{2,t-1},...y_{2,t-lags},...,y_{n,t-lags},0,0,...,0; ... ]
%%%% X_vec is a matrix (T-lags * (dimension*lags + dimension)) and exhibits
%%%% the form : X_vec(t,:) = [1
%%%% y_{1,t-1},y_{1,t-2},...,y_{1,t-lags},y_{2,t-1},...y_{2,t-lags},...,y_{n,t-lags}]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T = max(size(y));
if(T~=size(y,1))
    y = y';
end
dimension = min(size(y));

X_lags = zeros(lags,dimension,T-lags);
X_vec = zeros(T-lags,(dimension)*lags); %% y_{1,t-1},y_{1,t-2},...,y_{1,t-lags},y_{2,t-1},...y_{2,t-lags},...,y_{n,t-lags}, 
for i=lags+1:T
   for z=1:lags
       X_lags(z,:,i-lags) = y(i-z,:);
   end
   X_vec(i-lags,:) = reshape(X_lags(:,:,i-lags),1,(dimension)*lags);
   
end
X_vec = [ones(T-lags,1) X_vec];
y_lags = y(lags+1:T,:);
T = max(size(y_lags));
X_stack = zeros(dimension,dimension*(1+dimension*lags),T);
for t=1:T
   X_stack(:,:,t) = kron(eye(dimension),[X_vec(t,:)]);
end